function v=determineCompromiseQuality(Trajectory,Weights,Unanimity,bestExpert)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                  %
% Returns indicator, wether the unanimous decision                 %
% differs from experts initial opinion (best expert/experts mean)  %
% quality of 1 indicates no difference between experts opinion and %
% unanimous decison, 2 indicates difference and 0 indiates no      %
% unanimity (no quality control)                                   %
%                                                                  %
% Input: Trajectory := Model Trajectory, Weights := weight matrix  %
% (global variable), Unanimity := indicator of unanimity, 0 if not %
% reached, else non-zero, bestExperts := 1=yes, 0= all experts are %
% considered                                                       %
%                                                                  %
% Author: Gero Schwenk (Gero.Schwenk@web.de), August 25th 2006     %
%                                                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


nCycles=length(Trajectory(1,:));                %number of cycles
nAgents=length(Trajectory(:,1));                %number of agents
Expertize=zeros(nAgents,1);                     %vector of agents expertizes
quality=0;                                      %quality indicator
DecDistr=zeros(1,3);                            %frequency distribution of experts initial decisions

%---------collect complete expertize-vector from self weights and compute
%---------max and mean expertize

i=1;

for i=1:nAgents
    Expertize(i,1)=Weights(i,i);
    i=i+1;
end

mExpertize=mean(Expertize);
maxExpertize=max(Expertize);

%-------check wether there is unanimity, set indicator if unanimopus
%-------decison differs from experts initial decision

if bestExpert == 1                              %consider best expert
    
    i=1;
    for i=1:nAgents
        if Unanimity ~= 0                                                                       %if Unianimity
            if (Expertize(i,1) == maxExpertize) & (Trajectory(i,1) == Trajectory(i,nCycles))    %check wether best expert changed his mind
                quality=1;                                                                      %indicate no change of mind (good quality)
                break                                                                           %one is (per definition) enough    
            else
                quality=2;                                                                      %indicate change of mind (bad quality)
                break                                                                           %one is (per definition) enough 
            end    
        end                                                                                     %if no unanimity, quality is left 0
        i=i+1;
    end
    
elseif bestExpert == 0                          %consider all experts
    
    %--------compute mode initial decision of all experts
    
    i=1;
    for i=1:nAgents
        if Expertize(i,1) >= mExpertize         %if an expert
            if Trajectory(i,1) == 1             %determine decision distribution
                DecDistr(1,1)=DecDistr(1,1)+1;  
            elseif Trajectory(i,1) == 2
                DecDistr(1,2)=DecDistr(1,2)+1;
            elseif Trajectory(i,1) == 3
                DecDistr(1,3)=DecDistr(1,3)+1;
            end
        end
        i=1+1;
    end
    
       
    [B,IX] = sort(DecDistr,2);                                       %sort distribution
    
    if B(1,3) ~= B(1,2)                     %-------------if there is no tie regarding decision frequencies
        mode=IX(1,3);                                               %compute mode
        
        i=1;
        for i=1:nAgents
            if Unanimity ~= 0                                       %if unanimity has been reached
                if Expertize(i,1) >= mExpertize                     %if an expert
                    if Trajectory(i,1) == mode                      %if agent instantiates mode inital expert decision
                        if Trajectory(i,1) == Trajectory(i,nCycles) %if agent does not change his mind
                            quality=1;                              %indicate good quality decision
                            break                                   %one is enough (because of the mode-condition) 
                        else
                            quality=2;                              %else indicate bad quality decision
                            break                                   %one is enough (because of the mode-condition)
                        end
                    end
                end
            end
            i=i+1;
        end
        
    elseif B(1,3) == B(1,2)                 %-------------if there is a tie over two decision alternatives
        
        modeOne=IX(1,3);                    %determine modes
        modeTwo=IX(1,2);

    
        i=1;
        for i=1:nAgents
            if Unanimity ~= 0                                       %if unanimity has been reached
                if Expertize(i,1) >= mExpertize                     %if an expert
                    if Trajectory(i,1) == modeOne                   %if agent instantiates modeOne of inital expert decision
                        if Trajectory(i,1) == Trajectory(i,nCycles) %if agent does not change his mind
                            quality=1;                              %indicate good quality decision
                        else
                            quality=2;                              %else indicate bad quality decision
                        end
                    elseif Trajectory(i,1) == modeTwo               %if agent instantiates modeTwo of inital expert decision
                        if Trajectory(i,1) == Trajectory(i,nCycles) %if agent does not change his mind
                            quality=1;                              %indicate good quality decision
                        else
                            quality=2;                              %else indicate bad quality decision
                        end
                    end
                    if quality ~= 0
                        break                                       %one is enough (because of the mode-condition)
                    end
                end
                
            end
            i=i+1;
        end
        
    elseif B(1,3) == B(1,1)                 %-------------if there is a tie over all possible decision alternatives   
        quality=1;                                                 %indicate good quality decision, because nothing could go wrong
    end                
end

v=quality;
      



