function v=takeTheBestH(Type,indicator,Contacts,Decisions)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                  %
% Returns vector of agents decisions according to 'take the best'  %
% heuristic                                                        %
% decisions of other agent types are set to zero                   %
%                                                                  %                                                                  %
% Input: type := vector of agent type with regard to used          %
% heuristic; indicator := labeling number of 'take the best' agent %
% type, Contacts := Matrix of contacts influence weights (cue      %
% values); Decisions := Vector of Decisions                        %
%                                                                  %
% Author: Gero Schwenk (Gero.Schwenk@web.de), July 11th 2006       %
%                                                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



n=length(Type(:,1));
D=Decisions;

[SW,IX] = sort(Contacts,1)             %Sort (ascending) Contacts over columns (receiving node), 
                                        %return sorted matrix and indices

i=1;

for i=1:n                               %for all agents
    if Type(i,1) == indicator           %if agent uses 'take the best'
        D(i,1)=Decisions(IX(n,i),1);    %Choose the action of the one sorted as last, i.e. the most valid neighboring agent
    else
        D(i,1)=0;    
    end
    i=i+1;
end

v=D;

