%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                  %
% COMPUTES "localExRunMain",  which returns graphics of trajectory %
% of a small network which is entered manually.
%                                                                  %
% Author: Gero Schwenk (Gero.Schwenk@web.de), October 26th 2006    %
%                                                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear
tic


%----REPETITIONS
rep=1;

%----PARAMETERS
nUpdates=5;
nAgents=5;
nAlternatives=2;
tallying=3;
contactUniform=1;
decisionUniform=1;
contactType=4;                                         %ContactTypes: 1-minimalistTallied, 2-all, 3-TTB, 4-BE, 5-take proportional
decisionType=3;                                        %DecisionTypes: 1-conditionalMinimalist, 2-TTB, 3-UWM, 4-WAM, 5-take proportional

%IniDecList=[0;0;1;1;0;0;0;0;0;0;0;1;1;1;0;0;1;1;0;1;0;1;0;1;0;1;1;1;1;0;1;0;0;1;0;0];   %Empirical List of Initial Decisions
IniDecList=[1;1;2;2;2];                                %List of Initial Decisions

%empirical, weighted adjacency matrix
%AMatrix=influencingRates;

AMatrix=[0.8,0,0,0,0.8;                                % 5 Agents, agent 5 only recieving agent, network contains loops,
        0,0.5,0,0,0.5;                                 % decreasing status, agents 1 and 2 have status HE relative to 5
        0,0,0.3,0,0.3;                                 % agents 3 and 4 have status lower relative to five;
        0,0,0,0.2,0.2;                                 % agent 5 hat berdurchschnittlichen status (<s>=0.46)
        0,0,0,0,0.5;]

%----auxiliary parameters

global Weights;                                  %declaration "global" in main- and subfunctions makes "Weights" globally availiable;
                                                 %necessary for determination of expertize
                                        
all=0;                                           %parameters of proportionOpinionChange
experts=1;

allExperts=0;                                    %parameters of determineCompromiseQuality
bestExpert=1;

%----INSTRUCTIONS

UnanimityCycleVector=zeros(1,rep);               %vector of n(cycle) in which unanimity is reached
unAnimityVector=zeros(1,rep);                    %vector indicators (1/0) wether 1animity is reached        
twoAnimityVector=zeros(1,rep);                   %vector indicators (1/0) wether 2animity is reached
threeAnimityVector=zeros(1,rep);                 %vector indicators (1/0) wether 3animity is reached
proportionChangesVector=zeros(1,rep);            %vector of proportions of decision changes (all)
proportionExpertChangesVector=zeros(1,rep);      %vector of proportions of decision changes (experts)
CompromiseQualityVector=zeros(1,rep);            %vector of indicators (1/2, 0) wether unianimous decison differs from expert initial decision
CompromiseQualityVectorAllExperts=zeros(1,rep);  %vector of indicators (1/2, 0) wether unianimous decison differs from experts mode initial decision


k=1;
for k=1:rep                         %REPEAT SIMULATIONS AND COMPUTE AGGREGATE RESULTS
     
    %----compute trajectory
    
    Trajectory=graphicsRunAppl(nUpdates,nAgents,nAlternatives,tallying,contactUniform,decisionUniform,contactType,decisionType,IniDecList,AMatrix);
    
    EqilibriumAtCycle=equilibriumCycle(Trajectory)       %output equilibrium cycle
    
    %----increment loop
    
    k=k+1;
    
end                                 %END REPEAT SIMULATIONS

NoRep=rep                                 %output n repetitions
toc                                 %output time

%-----------plot ajacency matrix / trajectory is plotted in "graphicsRunHetero-------------------

figure
subplot(2,1,1); spy(Weights);             %plot binary adjacency matrix
    xlabel('Receiving Agent')
    ylabel('Exerting Agent')
    title('Adjacency Pattern')

subplot(2,1,2); stem3(Weights);             %plot weighted adjacency matrix
    xlabel('Receiving Agent')
    ylabel('Exerting Agent')
    zlabel('Weight')
    title('Weighted Ajacency Pattern')

    
    
