function v=smallWorld(n,dh,p)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                  %
% Returns adjacency matrix A of a small world network;             %
% Input: n := number of vertices; dh := minimum degree/2, d >= 1;  %
% p := propability of rewireing                                    %
%                                                                  %
% In addition to the original algorithm (see reference), also the  %
% upper diagonal of the adjacency matrix is instantiated, in order %
% to represent undirected relations. Furthermore the diagonal is   %
% set to 1, since the application explicitly assumes self loops.   %
%                                                                  %
% Reference: Albert, R., Barabasi. A.: 2002 'Statistical mechanics %
% of compelx networks', REVIEWS OF MODERN PHYSICS, VOL.74, pp.67   &
%                                                                  %
% Mail Ulrik Brandes "Fuer Deine Zwecke wuerde ich die Generatoren % 
% aber sowieso nicht mit diesem [anderen] Algorithmus              % 
% implementieren, sondern einfach Knoten v_0,...,v_{n-1} erzeugen, %
% jedes v_i mit den d/2 Vorgaengern und Nachfolgern (zyklisch)     %
% verbinden, und dann fuer jede Kante mit Wahrscheinlichkeit p     %
% einen neuen Nachbarn waehlen."                                   %
%                                                                  %
% Author: Gero Schwenk (Gero.Schwenk@web.de), June 13th 2006       %
%                                                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% d=2*dh;                       %PARAMETER AS IN REFERENCE
A=zeros(n,n);

i=1;
j=1;

%----------------------------CYCLIC CONNECTIONS(SYMMETRICAL)----------

for i=1:n-1                     %FOR ALL NODES
    for j=1:dh                  %FOR ALL dn NEIGHBORS IN ONE DIRECTION
        if i+j<=n               %IF NOT OVER BOUNDARY
            A(i,i+j)=1;         %CONNECT UPWARDS
        elseif i+j>n            %IF OVER BOUNDARY
            rh=dh-(j-1);        %CALCULATE REST OF NEIGHBOURS rh IN HIGHER CYCLE
            m=1;
            
            for m=1:rh
                A(i,m)=1;       %CONNECT UPWARDS IN HIGHER CYCLE
                m=m+1;
            end
        end
        if i-j >= 1             %IF dn OF LOWER NEIGHBOURS DOES NOT CROSS BOUNDARY
            A(i,i-j)=1;         %CONNECT DOWNWARDS
        elseif i-j < 1          %IF OVER BOUNDARY
            rl=dh-(j-1);        %CALCULATE REST OF NEIGBOURS rl IN LOWER CYCLE
            o=1;
            
            for o=1:rl
                A(i,(n+1)-o)=1; %CONNECT DOWNWARDS IN LOWER CYCLE
                o=o+1;
            end
            
        end
        j=j+1;
    end
    i=i+1;
end

k=1;

for k=1:dh                      %LAST NODE 
    A(n,k)=1;                   %CONNECT UPWARDS FROM LOWER BOUNDARY
    A(n,n-k)=1;                 %CONNECT DOWNWARDS FROM HIGHER BOUNDARY
end

%-----------------------REWIRE RANDOMLY----------------------------

i=1;
j=1;

for i=1:n
    for j=1:n
        r=rand(1);              %RANDOM NUMBER
        rj=ceil(rand(1)*(n));   %RANDOM JUMP
        while (rj == i)|(A(i,rj)~=0) %DONT JUMP TO DIAGONAL OR OCCUPIED EDGES
            rj=ceil(rand(1)*(n));
        end
        if (A(i,j)==1)          %IF EDGE EXISTS
            if r < p            %REWIRE WITH PROBABILITY p
                A(i,j)=0;       %DELETE OLD LINK
                A(i,rj)=1;      %LINK WITH RANDOM TARGET
                %A(rj,i)=1;      %SYMMETRISIZE
            end
        end
        j=j+1;
    end
    i=i+1;
end
             

%------------------------SET DIAGONAL TO ONE ----------------------

j = 1;
k = 1;

for j=1:n                            
    for k=1:n  
        if j == k                   
            A(j,k)=1;
        end
        k = k+1;
    end
    j = j+1;
end

%------------------------RETURN PARAMETER--------------------------

v=A;
        
